==> openshift-model-operator-4.11.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSZoneStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.openshift.api.model.DNSZoneFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.openshift.api.model.DNSZoneBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.openshift.api.model.DNSZone;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface DNSZoneStatusFluent<A extends DNSZoneStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,DNSZoneCondition item);
    public A setToConditions(int index,DNSZoneCondition item);
    public A addToConditions(DNSZoneCondition... items);
    public A addAllToConditions(Collection<DNSZoneCondition> items);
    public A removeFromConditions(DNSZoneCondition... items);
    public A removeAllFromConditions(Collection<DNSZoneCondition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<DNSZoneConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<DNSZoneCondition> getConditions();
    public List<DNSZoneCondition> buildConditions();
    public DNSZoneCondition buildCondition(int index);
    public DNSZoneCondition buildFirstCondition();
    public DNSZoneCondition buildLastCondition();
    public DNSZoneCondition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<DNSZoneConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<DNSZoneConditionBuilder> predicate);
    public A withConditions(List<DNSZoneCondition> conditions);
    public A withConditions(DNSZoneCondition... conditions);
    public Boolean hasConditions();
    public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
    public DNSZoneStatusFluent.ConditionsNested<A> addNewCondition();
    public DNSZoneStatusFluent.ConditionsNested<A> addNewConditionLike(DNSZoneCondition item);
    public DNSZoneStatusFluent.ConditionsNested<A> setNewConditionLike(int index,DNSZoneCondition item);
    public DNSZoneStatusFluent.ConditionsNested<A> editCondition(int index);
    public DNSZoneStatusFluent.ConditionsNested<A> editFirstCondition();
    public DNSZoneStatusFluent.ConditionsNested<A> editLastCondition();
    public DNSZoneStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<DNSZoneConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildDnsZone instead.
 * @return The buildable object.
 */
@Deprecated public DNSZone getDnsZone();
    public DNSZone buildDnsZone();
    public A withDnsZone(DNSZone dnsZone);
    public Boolean hasDnsZone();
    public DNSZoneStatusFluent.DnsZoneNested<A> withNewDnsZone();
    public DNSZoneStatusFluent.DnsZoneNested<A> withNewDnsZoneLike(DNSZone item);
    public DNSZoneStatusFluent.DnsZoneNested<A> editDnsZone();
    public DNSZoneStatusFluent.DnsZoneNested<A> editOrNewDnsZone();
    public DNSZoneStatusFluent.DnsZoneNested<A> editOrNewDnsZoneLike(DNSZone item);

    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSZoneConditionFluent<DNSZoneStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface DnsZoneNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSZoneFluent<DNSZoneStatusFluent.DnsZoneNested<N>>{

        
    public N and();    public N endDnsZone();
}


}

==> openshift-model-operator-5.0.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSZoneStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.openshift.api.model.DNSZoneFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.openshift.api.model.DNSZoneBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.openshift.api.model.DNSZone;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface DNSZoneStatusFluent<A extends DNSZoneStatusFluent<A>> extends Fluent<A> {


    public A addToConditions(int index,DNSZoneCondition item);
    public A setToConditions(int index,DNSZoneCondition item);
    public A addToConditions(DNSZoneCondition... items);
    public A addAllToConditions(Collection<DNSZoneCondition> items);
    public A removeFromConditions(DNSZoneCondition... items);
    public A removeAllFromConditions(Collection<DNSZoneCondition> items);
    public A removeMatchingFromConditions(Predicate<DNSZoneConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<DNSZoneCondition> getConditions();
    public List<DNSZoneCondition> buildConditions();
    public DNSZoneCondition buildCondition(int index);
    public DNSZoneCondition buildFirstCondition();
    public DNSZoneCondition buildLastCondition();
    public DNSZoneCondition buildMatchingCondition(Predicate<DNSZoneConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<DNSZoneConditionBuilder> predicate);
    public A withConditions(List<DNSZoneCondition> conditions);
    public A withConditions(DNSZoneCondition... conditions);
    public Boolean hasConditions();
    public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
    public DNSZoneStatusFluent.ConditionsNested<A> addNewCondition();
    public DNSZoneStatusFluent.ConditionsNested<A> addNewConditionLike(DNSZoneCondition item);
    public DNSZoneStatusFluent.ConditionsNested<A> setNewConditionLike(int index,DNSZoneCondition item);
    public DNSZoneStatusFluent.ConditionsNested<A> editCondition(int index);
    public DNSZoneStatusFluent.ConditionsNested<A> editFirstCondition();
    public DNSZoneStatusFluent.ConditionsNested<A> editLastCondition();
    public DNSZoneStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<DNSZoneConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildDnsZone instead.
 * @return The buildable object.
 */
@Deprecated public DNSZone getDnsZone();
    public DNSZone buildDnsZone();
    public A withDnsZone(DNSZone dnsZone);
    public Boolean hasDnsZone();
    public DNSZoneStatusFluent.DnsZoneNested<A> withNewDnsZone();
    public DNSZoneStatusFluent.DnsZoneNested<A> withNewDnsZoneLike(DNSZone item);
    public DNSZoneStatusFluent.DnsZoneNested<A> editDnsZone();
    public DNSZoneStatusFluent.DnsZoneNested<A> editOrNewDnsZone();
    public DNSZoneStatusFluent.DnsZoneNested<A> editOrNewDnsZoneLike(DNSZone item);
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSZoneConditionFluent<DNSZoneStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


    public interface DnsZoneNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSZoneFluent<DNSZoneStatusFluent.DnsZoneNested<N>> {

            public N and();
            public N endDnsZone();    }


}
